@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 
 from query import qfilter
+qf = qfilter
 
-__all__ = ['qfilter']
+__all__ = ['qf', 'qfilter']
